==> thirdparty-service-biz-1.0.27-2-sources.jar: cn/com/duiba/constant/ShanXiSecuritiesConfig.java <==
package cn.com.duiba.constant;

import com.google.common.collect.Sets;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.util.Set;

/**
 * @auther: linzhou$
 * @description: 山西证券配置类
 */
@Configuration
@ConfigurationProperties("shanxi.securities")
public class ShanXiSecuritiesConfig {

    private Set<Long> appIds = Sets.newHashSet(80936L);

    private String apiSecret = "irjAuhv0eRnx83naMsj";
    private String appCode = "EXCHANGE";

    /**
     * 加积分、减积分
     */
//    private String insertPointDetailUrl = "https://jfhd.i618.com.cn:8602/pointCenter/point/insertPointDetail";
    /**
     * 查询用户积分
     */
    private String getCustomerPointUrl = "https://jfhd.i618.com.cn:8602/pointCenter/point/getCustomerPoint";

    private Integer length = 8;

    public Integer getLength() {
        return length;
    }

    public void setLength(Integer length) {
        this.length = length;
    }

    public Set<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(Set<Long> appIds) {
        this.appIds = appIds;
    }

    public String getApiSecret() {
        return apiSecret;
    }

    public void setApiSecret(String apiSecret) {
        this.apiSecret = apiSecret;
    }

    public String getAppCode() {
        return appCode;
    }

    public void setAppCode(String appCode) {
        this.appCode = appCode;
    }

    public String getGetCustomerPointUrl() {
        return getCustomerPointUrl;
    }

    public void setGetCustomerPointUrl(String getCustomerPointUrl) {
        this.getCustomerPointUrl = getCustomerPointUrl;
    }

//    public String getInsertPointDetailUrl() {
//        return insertPointDetailUrl;
//    }
//
//    public void setInsertPointDetailUrl(String insertPointDetailUrl) {
//        this.insertPointDetailUrl = insertPointDetailUrl;
//    }
}

==> thirdparty-service-biz-1.0.57-sources.jar: cn/com/duiba/constant/ShanXiSecuritiesConfig.java <==
package cn.com.duiba.constant;

import com.google.common.collect.Sets;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.util.Set;

/**
 * @auther: linzhou$
 * @description: 山西证券配置类
 */
@Configuration
@ConfigurationProperties("shanxi.securities")
public class ShanXiSecuritiesConfig {

    private Set<Long> appIds = Sets.newHashSet(80936L);

    private String apiSecret = "irjAuhv0eRnx83naMsj";
    private String appCode = "EXCHANGE";

    /**
     * 加积分、减积分
     */
    private String insertPointDetailUrl = "https://jfhd.i618.com.cn:8602/pointCenter/point/insertPointDetail";
    /**
     * 查询用户积分
     */
    private String getCustomerPointUrl = "https://jfhd.i618.com.cn:8602/pointCenter/point/getCustomerPoint";
    /**
     * 发券
     */
    private String getGiveCouponUrl = "https://jfhd.i618.com.cn:8602/coupon/h5/thirdopen/giveCoupon";

    private Integer length = 8;

    public Integer getLength() {
        return length;
    }

    public void setLength(Integer length) {
        this.length = length;
    }

    public Set<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(Set<Long> appIds) {
        this.appIds = appIds;
    }

    public String getApiSecret() {
        return apiSecret;
    }

    public void setApiSecret(String apiSecret) {
        this.apiSecret = apiSecret;
    }

    public String getAppCode() {
        return appCode;
    }

    public void setAppCode(String appCode) {
        this.appCode = appCode;
    }

    public String getGetCustomerPointUrl() {
        return getCustomerPointUrl;
    }

    public void setGetCustomerPointUrl(String getCustomerPointUrl) {
        this.getCustomerPointUrl = getCustomerPointUrl;
    }

    public String getInsertPointDetailUrl() {
        return insertPointDetailUrl;
    }

    public void setInsertPointDetailUrl(String insertPointDetailUrl) {
        this.insertPointDetailUrl = insertPointDetailUrl;
    }

    public String getGetGiveCouponUrl() {
        return getGiveCouponUrl;
    }

    public void setGetGiveCouponUrl(String getGiveCouponUrl) {
        this.getGiveCouponUrl = getGiveCouponUrl;
    }
}
